@@ -1,8 +1,7 @@
 """nginx plugin constants."""
 import platform
-
-from acme.magic_typing import Any
-from acme.magic_typing import Dict
+from typing import Any
+from typing import Dict
 
 FREEBSD_DARWIN_SERVER_ROOT = "/usr/local/etc/nginx"
 LINUX_SERVER_ROOT = "/etc/nginx"
@@ -15,19 +14,21 @@ elif platform.system() in ('NetBSD',):
 else:
     server_root_tmp = LINUX_SERVER_ROOT
 
-CLI_DEFAULTS = dict(
-    server_root=server_root_tmp,
-    ctl="nginx",
-    sleep_seconds=1
-) # type: Dict[str, Any]
+CLI_DEFAULTS: Dict[str, Any] = {
+    "server_root": server_root_tmp,
+    "ctl": "nginx",
+    "sleep_seconds": 1
+}
 """CLI defaults."""
 
 
 MOD_SSL_CONF_DEST = "options-ssl-nginx.conf"
-"""Name of the mod_ssl config file as saved in `IConfig.config_dir`."""
+"""Name of the mod_ssl config file as saved
+in `certbot.configuration.NamespaceConfig.config_dir`."""
 
 UPDATED_MOD_SSL_CONF_DIGEST = ".updated-options-ssl-nginx-conf-digest.txt"
-"""Name of the hash of the updated or informed mod_ssl_conf as saved in `IConfig.config_dir`."""
+"""Name of the hash of the updated or informed mod_ssl_conf as saved
+in `certbot.configuration.NamespaceConfig.config_dir`."""
 
 ALL_SSL_OPTIONS_HASHES = [
     '0f81093a1465e3d4eaa8b0c14e77b2a2e93568b0fc1351c2b87893a95f0de87c',
@@ -51,7 +52,8 @@ ALL_SSL_OPTIONS_HASHES = [
 ]
 """SHA256 hashes of the contents of all versions of MOD_SSL_CONF_SRC"""
 
-def os_constant(key):
+
+def os_constant(key: str) -> Any:
     # XXX TODO: In the future, this could return different constants
     #           based on what OS we are running under.  To see an
     #           approach to how to handle different OSes, see the
@@ -60,11 +62,12 @@ def os_constant(key):
     """
     Get a constant value for operating system
 
-    :param key: name of cli constant
+    :param str key: name of cli constant
     :return: value of constant for active os
     """
     return CLI_DEFAULTS[key]
 
+
 HSTS_ARGS = ['\"max-age=31536000\"', ' ', 'always']
 
 HEADER_ARGS = {'Strict-Transport-Security': HSTS_ARGS}
